# frozen_string_literal: true

require 'spec_helper'

RSpec.describe VulnerabilityPresenter do
  let(:project) { create(:project) }
  let(:pipeline) { create(:ci_pipeline, :success, project: project) }
  let(:finding) { create(:vulnerabilities_finding, :with_secret_detection, pipelines: [pipeline], project: project) }

  subject  { described_class.new(finding.vulnerability) }

  describe '#location_link_with_raw_path' do
    it 'returns the location link in raw format' do
      path = subject.location_link_with_raw_path

      expect(path).to include('raw')
      expect(path).to include(finding.file)
      expect(path).to include("#L#{finding.location['start_line']}")
    end
  end

  describe '#location_link' do
    it 'returns the location link in blob format' do
      path = subject.location_link

      expect(path).to include('blob')
      expect(path).to include(finding.file)
      expect(path).to include("#L#{finding.location['start_line']}")
    end
  end
end
